==> alfresco-repository-23.3.15.1-sources.jar: org/alfresco/repo/jscript/BaseScopableProcessorExtension.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.jscript;

import org.alfresco.api.AlfrescoPublicApi;     
import org.alfresco.repo.processor.BaseProcessorExtension;
import org.mozilla.javascript.Scriptable;

/**
 * Abstract base class for a script implementation that requires a script execution scope.
 * 
 * The scope is local to the currently executing script and therefore a ThreadLocal is required.
 * 
 * @author Kevin Roast
 */
@AlfrescoPublicApi
public class BaseScopableProcessorExtension extends BaseProcessorExtension implements Scopeable
{
    private static ThreadLocal<Scriptable> scope = new ThreadLocal<Scriptable>();
    
    /**
     * Set the Scriptable global scope
     * 
     * @param scope relative global scope
     */
    public void setScope(Scriptable scope)
    {
        BaseScopableProcessorExtension.scope.set(scope);
    }
    
    /**
     * @return script global scope
     */
    public Scriptable getScope()
    {
        return BaseScopableProcessorExtension.scope.get();
    }
}

==> alfresco-repository-25.4.0.7-sources.jar: org/alfresco/repo/jscript/BaseScopableProcessorExtension.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.jscript;

import org.mozilla.javascript.Scriptable;

import org.alfresco.api.AlfrescoPublicApi;
import org.alfresco.repo.processor.BaseProcessorExtension;

/**
 * Abstract base class for a script implementation that requires a script execution scope.
 * 
 * The scope is local to the currently executing script and therefore a ThreadLocal is required.
 * 
 * @author Kevin Roast
 */
@AlfrescoPublicApi
public class BaseScopableProcessorExtension extends BaseProcessorExtension implements Scopeable
{
    private static ThreadLocal<Scriptable> scope = new ThreadLocal<Scriptable>();

    /**
     * Set the Scriptable global scope
     * 
     * @param scope
     *            relative global scope
     */
    public void setScope(Scriptable scope)
    {
        BaseScopableProcessorExtension.scope.set(scope);
    }

    /**
     * @return script global scope
     */
    public Scriptable getScope()
    {
        return BaseScopableProcessorExtension.scope.get();
    }
}
